@@ -35,9 +35,9 @@ pub fn first_pkt_len() -> u32 {
 ///
 /// idx < 0 means **ban**.
 /// idx = 0 means **default**.
-pub fn decide_remote_idx(buf: *const u8) -> i32 {
+pub fn decide_remote_idx(idx: i32, buf: *const u8) -> i32 {
     call_ffi!(
-        DYLIB, b"realm_decide_remote_idx" => unsafe extern "C" fn(*const u8) -> i32,
-        buf
+        DYLIB, b"realm_decide_remote_idx" => unsafe extern "C" fn(i32, *const u8) -> i32,
+        idx, buf
     )
 }
